@@ -83,9 +83,11 @@ def print_info(path):
             ['Completed', summary.get_completed()],
             ['Restored', header.initial.restore_time > 0],
             ['Postgame', bool(summary.get_postgame())],
-            ['Version', '{} ({}, {})'.format(header.version.name, header.game_version, round(header.save_version, 2))],
+            ['Objects', bool(summary.get_objects()['objects'])],
+            ['Version', '{} ({}, {}, {})'.format(header.version.name, header.game_version, header.save_version, header.log_version)],
             ['Dataset', '{} {}'.format(dataset['name'], dataset['version'])],
-            ['Hash', summary.get_hash().hexdigest()],
+            ['File Hash', summary.get_file_hash()],
+            ['Match Hash', summary.get_hash().hexdigest() if summary.get_hash() else None],
             ['Encoding', summary.get_encoding()],
             ['Language', summary.get_language()],
             ['Map', '{} ({})'.format(summary.get_map()['name'], summary.get_map()['seed'])] # pylint: disable=unsubscriptable-object
