@@ -46,6 +46,7 @@ DE_MAP_NAMES = {
     31: 'Oasis',
     32: 'Ghost Lake',
     33: 'Random Land Map',
+    51: 'Mideast',
     # 59: Custom
     67: 'Acropolis',
     68: 'Budapest',
@@ -64,6 +65,7 @@ DE_MAP_NAMES = {
     81: 'CtR Pyramid Descent',
     82: 'CtR Spiral',
     86: 'Serengeti',
+    108: 'Indochina',
     112: 'Bog Islands',
     122: 'Alpine Lakes',
     125: 'Ravines',
