@@ -1,8 +1,9 @@
 """Definitive Edition structure."""
 
 from construct import (
-    Struct, Int32ul, Float32l, Array, Padding, Flag,
-    Byte, Int16ul, Bytes, Int32sl, Peek, Const, RepeatUntil
+    Struct, Int32ul, Float32l, Array, Padding, Flag, If,
+    Byte, Int16ul, Bytes, Int32sl, Peek, Const, RepeatUntil,
+    Int64ul
 )
 
 from mgz.enums import VictoryEnum, ResourceLevelEnum, AgeEnum, PlayerTypeEnum, DifficultyEnum
@@ -18,15 +19,15 @@ de_string = Struct(
 separator = Const(b"\xa3_\x02\x00")
 
 de = "de"/Struct(
-    "options"/Int32sl,
-    Int32ul,
-    Int32ul,
+    "version"/Float32l,
+    "interval_version"/Int32ul,
+    "game_options_version"/Int32ul,
     "dlc_count"/Int32ul,
     "dlc_ids"/Array(lambda ctx: ctx.dlc_count, Int32ul),
-    Bytes(4),
+    "dataset_ref"/Int32ul,
     "difficulty"/DifficultyEnum(Int32ul),
-    "map_size"/Int32ul,
-    "map_id"/Int32ul,
+    "selected_map_id"/Int32ul,
+    "resolved_map_id"/Int32ul,
     "reveal_map"/Int32ul,
     Peek("victory_type_id"/Int32ul),
     VictoryEnum("victory_type"/Int32ul),
@@ -43,8 +44,8 @@ de = "de"/Struct(
     "treaty_length"/Int32ul,
     "population_limit"/Int32ul,
     "num_players"/Int32ul,
-    Int32ul,
-    Int32ul,
+    "unused_player_color"/Int32ul,
+    "victory_amount"/Int32ul,
     separator,
     "trade_enabled"/Flag,
     "team_bonus_disabled"/Flag,
@@ -58,36 +59,40 @@ de = "de"/Struct(
     "record_game"/Flag,
     "animals_enabled"/Flag,
     "predators_enabled"/Flag,
-    Bytes(3),
+    "turbo_enabled"/Flag,
+    "shared_exploration"/Flag,
+    "team_positions"/Flag,
     separator,
     "players"/Array(8, Struct(
         "dlc_id"/Int32ul,
         "color_id"/Int32sl,
         "selected_color"/Byte,
-        Byte,
-        "team_id"/Byte,
-        Bytes(9),
+        "selected_team_id"/Byte,
+        "resolved_team_id"/Byte,
+        "dat_crc"/Bytes(8),
+        "mp_game_version"/Byte,
         "civ_id"/Byte,
         Const(b"\x00\x00\x00"),
         "ai_type"/de_string,
-        Byte,
+        "ai_civ_name_index"/Byte,
         "ai_name"/de_string,
         "name"/de_string,
         "type"/PlayerTypeEnum(Int32ul),
         "profile_id"/Int32ul,
         Const(b"\x00\x00\x00\x00"),
         "player_number"/Int32sl,
-        Bytes(10),
+        "hd_rm_elo"/Int32ul,
+        "hd_dm_elo"/Int32ul,
+        "animated_destruction_enabled"/Flag,
+        "custom_ai"/Flag
     )),
     "fog_of_war"/Flag,
     "cheat_notifications"/Flag,
     "colored_chat"/Flag,
-    Bytes(4),
-    "ranked"/Flag,
-    "allow_specs"/Flag,
-    Bytes(3),
+    Bytes(9),
     separator,
     Bytes(12),
+    If(lambda ctx: ctx._.save_version >= 13.13, Bytes(5)),
     "strings"/Array(23,
         Struct(
             "string"/de_string,
@@ -95,8 +100,7 @@ de = "de"/Struct(
         )
     ),
     "strategic_numbers"/Array(59, Int32sl),
-    "num_ai_files"/Int32ul,
-    Const(b"\x00\x00\x00\x00"),
+    "num_ai_files"/Int64ul,
     "ai_files"/Array(lambda ctx: ctx.num_ai_files, Struct(
         Bytes(4),
         "name"/de_string,
@@ -104,10 +108,12 @@ de = "de"/Struct(
     )),
     "guid"/Bytes(16),
     "lobby_name"/de_string,
-    de_string,
+    "modded_dataset"/de_string,
     Bytes(19),
+    If(lambda ctx: ctx._.save_version >= 13.13, Bytes(5)),
     de_string,
     Bytes(5),
+    If(lambda ctx: ctx._.save_version >= 13.13, Byte),
     de_string,
     Int32ul,
     Bytes(4) # usually zero
