@@ -7,6 +7,7 @@ import os
 import struct
 import tempfile
 import time
+import uuid
 import zlib
 
 import construct
@@ -89,6 +90,7 @@ class Summary: # pylint: disable=too-many-public-methods
         rated = None
         i = 0
         duration = self._header.initial.restore_time
+        fast.meta(self._handle)
         while True:
             try:
                 operation, payload = fast.operation(self._handle)
@@ -173,7 +175,7 @@ class Summary: # pylint: disable=too-many-public-methods
 
     def get_version(self):
         """Get game version."""
-        return self._header.version, self._header.game_version, self._header.save_version
+        return self._header.version, self._header.game_version, self._header.save_version, self._header.log_version
 
     def get_owner(self):
         """Get rec owner (POV)."""
@@ -193,9 +195,9 @@ class Summary: # pylint: disable=too-many-public-methods
         """Get map of player color to profile IDs (DE only)."""
         if self._header.version == Version.DE:
             return {
-                p.color_id: p.profile_id
+                p.player_number: p.profile_id
                 for p in self._header.de.players
-                if p.color_id >= 0 and p.profile_id > 0
+                if p.player_number >= 0 and p.profile_id > 0
             }
         return {}
 
@@ -225,16 +227,13 @@ class Summary: # pylint: disable=too-many-public-methods
     def get_platform(self):
         """Get platform data."""
         lobby_name = None
-        guid_formatted = None
+        guid = None
         if self._header.version == Version.DE:
             lobby_name = self._header.de.lobby_name.value.decode(self.get_encoding()).strip()
-            guid = self._header.de.guid.hex()
-            guid_formatted = '{}-{}-{}-{}-{}'.format(
-                guid[0:8], guid[8:12], guid[12:16], guid[16:20], guid[20:]
-            )
+            guid = str(uuid.UUID(bytes=self._header.de.guid))
         return {
             'platform_id': self._cache['platform_id'],
-            'platform_match_id': guid_formatted,
+            'platform_match_id': guid,
             'ladder': self._cache['ladder'],
             'rated': self._cache['rated'],
             'ratings': self._cache['ratings'],
