@@ -27,7 +27,8 @@ class Version(Enum):
     for consistency.
     """
     AOK = 1
-    AOC = 5
+    AOC = 4
+    AOC10 = 5
     AOC10C = 8
     USERPATCH12 = 12
     USERPATCH13 = 13
@@ -64,12 +65,16 @@ class ZlibCompressed(Tunnel):
         return zlib.decompress(data, wbits=-15)
 
 
-def get_version(game_version, save_version):
+def get_version(game_version, save_version, log_version):
     """Get version based on version fields."""
     if game_version == 'VER 9.3':
         return Version.AOK
     if game_version == 'VER 9.4':
-        if save_version >= 12.97:
+        if log_version == 3:
+            return Version.AOC10
+        if log_version == 4:
+            return Version.AOC10C
+        if log_version == 5 or save_version >= 12.97:
             return Version.DE
         return Version.AOC
     if game_version == 'VER 9.8':
@@ -82,7 +87,8 @@ def get_version(game_version, save_version):
         return Version.USERPATCH14
     if game_version in ['VER 9.E', 'VER 9.F']:
         return Version.USERPATCH15
-    raise ValueError('unsupported version: {}, {}'.format(game_version, save_version))
+    if log_version is not None or game_version != 'VER 9.4':
+        raise ValueError('unsupported version: {}, {}, {}'.format(game_version, save_version, log_version))
 
 
 def find_version(ctx):
@@ -158,6 +164,8 @@ class Find(Construct):
     def __init__(self, find, max_length):
         """Initiallize."""
         Construct.__init__(self)
+        if not isinstance(find, list):
+            find = [find]
         self.find = find
         self.max_length = max_length
 
@@ -169,9 +177,14 @@ class Find(Construct):
             read_bytes = stream.read(self.max_length)
         else:
             read_bytes = stream.read()
-        skip = read_bytes.find(self.find) + len(self.find)
-        stream.seek(start + skip)
-        return skip
+        for f in self.find:
+            pos = read_bytes.find(f)
+            if pos == -1:
+                continue
+            skip = pos + len(f)
+            stream.seek(start + skip)
+            return skip
+        raise RuntimeError('could not find bytes')
 
 
 class RepeatUpTo(Subconstruct):
